summaryrefslogtreecommitdiff
path: root/drivers/staging/tidspbridge/include/dspbridge
diff options
context:
space:
mode:
authorRene Sapiens <rene.sapiens@ti.com>2010-07-09 21:24:01 -0500
committerGreg Kroah-Hartman <gregkh@suse.de>2010-07-22 10:45:35 -0700
commitdaa89e6cdf1ad0ba18680f41237b659ef0c27c72 (patch)
treebf59bd9ab2c90893de208ec4e4056f428ac662b6 /drivers/staging/tidspbridge/include/dspbridge
parente436d07db9db374105daa6c15d853e3f13a37104 (diff)
staging: ti dspbridge: Rename words with camel case
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== phNldrObj to nldr_ovlyobj phNldr to nldr phNodeMgr to node_man pHostBuf to host_buf pHostConfig to host_config phRmmMgr to rmm_mgr phStrmMgr to strm_man phStrm to strm_objct phXlator to xlator physicalAddr to physical_addr pInfo to channel_info pIOC to chan_ioc pLib to lib_obj pList to lst pMemBuf to mem_buf ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/cmm.h6
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/cod.h4
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dbll.h3
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dblldefs.h10
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dev.h28
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dspchnl.h6
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dspdefs.h42
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/list.h60
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/nldr.h4
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/nldrdefs.h10
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/node.h14
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/nodepriv.h6
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/strm.h20
13 files changed, 107 insertions, 106 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/cmm.h b/drivers/staging/tidspbridge/include/dspbridge/cmm.h
index d36972eca3d..22d053b3be1 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/cmm.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/cmm.h
@@ -281,7 +281,7 @@ extern void *cmm_xlator_alloc_buf(struct cmm_xlatorobject *xlator,
* address translation. Node messaging and streams use this to perform
* inter-processor(GPP<->DSP) zero-copy data transfer.
* Parameters:
- * phXlator: Address to place handle to a new Xlator handle.
+ * xlator: Address to place handle to a new Xlator handle.
* hcmm_mgr: Handle to Cmm Mgr associated with this translator.
* pXlatorAttrs: Translator attributes used for the client NODE or STREAM.
* Returns:
@@ -289,13 +289,13 @@ extern void *cmm_xlator_alloc_buf(struct cmm_xlatorobject *xlator,
* -EINVAL: Bad input Attrs.
* -ENOMEM: Insufficient memory(local) for requested resources.
* Requires:
- * phXlator != NULL
+ * xlator != NULL
* hcmm_mgr != NULL
* pXlatorAttrs != NULL
* Ensures:
*
*/
-extern int cmm_xlator_create(OUT struct cmm_xlatorobject **phXlator,
+extern int cmm_xlator_create(OUT struct cmm_xlatorobject **xlator,
struct cmm_object *hcmm_mgr,
struct cmm_xlatorattrs *pXlatorAttrs);
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dbll.h b/drivers/staging/tidspbridge/include/dspbridge/dbll.h
index daf81052701..63785558e35 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dbll.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dbll.h
@@ -45,7 +45,8 @@ extern int dbll_load(struct dbll_library_obj *lib,
extern int dbll_load_sect(struct dbll_library_obj *lib,
char *sectName, struct dbll_attrs *attrs);
extern int dbll_open(struct dbll_tar_obj *target, char *file,
- dbll_flags flags, struct dbll_library_obj **pLib);
+ dbll_flags flags,
+ struct dbll_library_obj **lib_obj);
extern int dbll_read_sect(struct dbll_library_obj *lib,
char *name, char *pbuf, u32 size);
extern void dbll_set_attrs(struct dbll_tar_obj *target,
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dspchnl.h b/drivers/staging/tidspbridge/include/dspbridge/dspchnl.h
index c0092040b0d..a4e0c849cd5 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dspchnl.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dspchnl.h
@@ -41,12 +41,12 @@ extern int bridge_chnl_open(OUT struct chnl_object **chnl,
extern int bridge_chnl_close(struct chnl_object *chnl_obj);
extern int bridge_chnl_add_io_req(struct chnl_object *chnl_obj,
- void *pHostBuf,
+ void *host_buf,
u32 byte_size, u32 buf_size,
OPTIONAL u32 dw_dsp_addr, u32 dw_arg);
extern int bridge_chnl_get_ioc(struct chnl_object *chnl_obj,
- u32 timeout, OUT struct chnl_ioc *pIOC);
+ u32 timeout, OUT struct chnl_ioc *chan_ioc);
extern int bridge_chnl_cancel_io(struct chnl_object *chnl_obj);
@@ -54,7 +54,7 @@ extern int bridge_chnl_flush_io(struct chnl_object *chnl_obj,
u32 timeout);
extern int bridge_chnl_get_info(struct chnl_object *chnl_obj,
- OUT struct chnl_info *pInfo);
+ OUT struct chnl_info *channel_info);
extern int bridge_chnl_get_mgr_info(struct chnl_mgr *hchnl_mgr,
u32 uChnlID, OUT struct chnl_mgrinfo
diff --git a/drivers/staging/tidspbridge/include/dspbridge/list.h b/drivers/staging/tidspbridge/include/dspbridge/list.h
index 2cf885d7a99..6837b614073 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/list.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/list.h
@@ -35,18 +35,18 @@ struct lst_list {
* Returns a pointer to the first element of the list, or NULL if the list
* is empty.
* Parameters:
- * pList: Pointer to list control structure.
+ * lst: Pointer to list control structure.
* Returns:
* Pointer to first list element, or NULL.
* Requires:
* - LST initialized.
- * - pList != NULL.
+ * - lst != NULL.
* Ensures:
*/
-static inline struct list_head *lst_first(struct lst_list *pList)
+static inline struct list_head *lst_first(struct lst_list *lst)
{
- if (pList && !list_empty(&pList->head))
- return pList->head.next;
+ if (lst && !list_empty(&lst->head))
+ return lst->head.next;
return NULL;
}
@@ -64,30 +64,30 @@ static inline struct list_head *lst_first(struct lst_list *pList)
* element. So the next element after the head becomes the new head of
* the list.
* Parameters:
- * pList: Pointer to list control structure of list whose head
+ * lst: Pointer to list control structure of list whose head
* element is to be removed
* Returns:
* Pointer to element that was at the head of the list (success)
* NULL No elements in list
* Requires:
* - LST initialized.
- * - pList != NULL.
+ * - lst != NULL.
* Ensures:
* Notes:
* Because the tail of the list points forward (its "next" pointer) to
* the head of the list, and the head of the list points backward (its
* "prev" pointer) to the tail of the list, this list is circular.
*/
-static inline struct list_head *lst_get_head(struct lst_list *pList)
+static inline struct list_head *lst_get_head(struct lst_list *lst)
{
struct list_head *elem_list;
- if (!pList || list_empty(&pList->head))
+ if (!lst || list_empty(&lst->head))
return NULL;
- elem_list = pList->head.next;
- pList->head.next = elem_list->next;
- elem_list->next->prev = &pList->head;
+ elem_list = lst->head.next;
+ lst->head.next = elem_list->next;
+ elem_list->next->prev = &lst->head;
return elem_list;
}
@@ -121,22 +121,22 @@ static inline void lst_init_elem(struct list_head *elem_list)
* Purpose:
* Insert the element before the existing element.
* Parameters:
- * pList: Pointer to list control structure.
+ * lst: Pointer to list control structure.
* elem_list: Pointer to element in list to insert.
* elem_existing: Pointer to existing list element.
* Returns:
* Requires:
* - LST initialized.
- * - pList != NULL.
+ * - lst != NULL.
* - elem_list != NULL.
* - elem_existing != NULL.
* Ensures:
*/
-static inline void lst_insert_before(struct lst_list *pList,
+static inline void lst_insert_before(struct lst_list *lst,
struct list_head *elem_list,
struct list_head *elem_existing)
{
- if (pList && elem_list && elem_existing)
+ if (lst && elem_list && elem_existing)
list_add_tail(elem_list, elem_existing);
}
@@ -146,21 +146,21 @@ static inline void lst_insert_before(struct lst_list *pList,
* Returns a pointer to the next element of the list, or NULL if the next
* element is the head of the list or the list is empty.
* Parameters:
- * pList: Pointer to list control structure.
+ * lst: Pointer to list control structure.
* cur_elem: Pointer to element in list to remove.
* Returns:
* Pointer to list element, or NULL.
* Requires:
* - LST initialized.
- * - pList != NULL.
+ * - lst != NULL.
* - cur_elem != NULL.
* Ensures:
*/
-static inline struct list_head *lst_next(struct lst_list *pList,
+static inline struct list_head *lst_next(struct lst_list *lst,
struct list_head *cur_elem)
{
- if (pList && !list_empty(&pList->head) && cur_elem &&
- (cur_elem->next != &pList->head))
+ if (lst && !list_empty(&lst->head) && cur_elem &&
+ (cur_elem->next != &lst->head))
return cur_elem->next;
return NULL;
}
@@ -179,13 +179,13 @@ static inline struct list_head *lst_next(struct lst_list *pList,
* Sets new element's next pointer to the address of the head element.
* Sets head's prev pointer to the address of the new element.
* Parameters:
- * pList: Pointer to list control structure to which *elem_list will be
+ * lst: Pointer to list control structure to which *elem_list will be
* added
* elem_list: Pointer to list element to be added
* Returns:
* Void
* Requires:
- * *elem_list and *pList must both exist.
+ * *elem_list and *lst must both exist.
* LST initialized.
* Ensures:
* Notes:
@@ -193,11 +193,11 @@ static inline struct list_head *lst_next(struct lst_list *pList,
* tail's "next" pointer points at the head of the list, and the head's
* "prev" pointer points at the tail of the list), the list is circular.
*/
-static inline void lst_put_tail(struct lst_list *pList,
+static inline void lst_put_tail(struct lst_list *lst,
struct list_head *elem_list)
{
- if (pList && elem_list)
- list_add_tail(elem_list, &pList->head);
+ if (lst && elem_list)
+ list_add_tail(elem_list, &lst->head);
}
/*
@@ -206,19 +206,19 @@ static inline void lst_put_tail(struct lst_list *pList,
* Removes (unlinks) the given element from the list, if the list is not
* empty. Does not free the list element.
* Parameters:
- * pList: Pointer to list control structure.
+ * lst: Pointer to list control structure.
* cur_elem: Pointer to element in list to remove.
* Returns:
* Requires:
* - LST initialized.
- * - pList != NULL.
+ * - lst != NULL.
* - cur_elem != NULL.
* Ensures:
*/
-static inline void lst_remove_elem(struct lst_list *pList,
+static inline void lst_remove_elem(struct lst_list *lst,
struct list_head *cur_elem)
{
- if (pList && !list_empty(&pList->head) && cur_elem)
+ if (lst && !list_empty(&lst->head) && cur_elem)
list_del_init(cur_elem);
}
diff --git a/drivers/staging/tidspbridge/include/dspbridge/nldr.h b/drivers/staging/tidspbridge/include/dspbridge/nldr.h
index 3482fe3d521..b2bfb5eb11e 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/nldr.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/nldr.h
@@ -31,7 +31,7 @@ extern int nldr_allocate(struct nldr_object *nldr_obj,
OUT struct nldr_nodeobject **nldr_nodeobj,
IN bool *pf_phase_split);
-extern int nldr_create(OUT struct nldr_object **phNldr,
+extern int nldr_create(OUT struct nldr_object **nldr,
struct dev_object *hdev_obj,
IN CONST struct nldr_attrs *pattrs);
@@ -42,7 +42,7 @@ extern int nldr_get_fxn_addr(struct nldr_nodeobject *nldr_node_obj,
char *pstrFxn, u32 * pulAddr);
extern int nldr_get_rmm_manager(struct nldr_object *nldr,
- OUT struct rmm_target_obj **phRmmMgr);
+ OUT struct rmm_target_obj **rmm_mgr);
extern bool nldr_init(void);
extern int nldr_load(struct nldr_nodeobject *nldr_node_obj,
diff --git a/drivers/staging/tidspbridge/include/dspbridge/nldrdefs.h b/drivers/staging/tidspbridge/include/dspbridge/nldrdefs.h
index 17c5d70f001..e15ef678981 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/nldrdefs.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/nldrdefs.h
@@ -141,7 +141,7 @@ typedef int(*nldr_allocatefxn) (struct nldr_object *nldr_obj,
* create, delete, and execute phase functions of nodes on the DSP target.
*
* Parameters:
- * phNldr: Location to store loader handle on output.
+ * nldr: Location to store loader handle on output.
* hdev_obj: Device for this processor.
* pattrs: Loader attributes.
* Returns:
@@ -149,14 +149,14 @@ typedef int(*nldr_allocatefxn) (struct nldr_object *nldr_obj,
* -ENOMEM: Insufficient memory for requested resources.
* Requires:
* nldr_init(void) called.
- * phNldr != NULL.
+ * nldr != NULL.
* hdev_obj != NULL.
* pattrs != NULL.
* Ensures:
- * 0: Valid *phNldr.
- * error: *phNldr == NULL.
+ * 0: Valid *nldr.
+ * error: *nldr == NULL.
*/
-typedef int(*nldr_createfxn) (OUT struct nldr_object **phNldr,
+typedef int(*nldr_createfxn) (OUT struct nldr_object **nldr,
struct dev_object *hdev_obj,
IN CONST struct nldr_attrs *pattrs);
diff --git a/drivers/staging/tidspbridge/include/dspbridge/cod.h b/drivers/staging/tidspbridge/include/dspbridge/cod.h
index 63bb87457d2..0cc1bd2bffd 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/cod.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/cod.h
@@ -307,7 +307,7 @@ extern int cod_load_base(struct cod_manager *cod_mgr_obj,
* pszCoffPath: Coff file to open.
* flags: COD_NOLOAD (don't load symbols) or COD_SYMB (load
* symbols).
* pLib: Handle returned that can be used in calls to cod_close
* and cod_get_section.
* Returns:
* S_OK: Success.
@@ -321,7 +321,7 @@ extern int cod_load_base(struct cod_manager *cod_mgr_obj,
*/
extern int cod_open(struct cod_manager *hmgr,
IN char *pszCoffPath,
- u32 flags, OUT struct cod_libraryobj **pLib);
+ u32 flags, OUT struct cod_libraryobj **lib_obj);
/*
* ======== cod_open_base ========
@@ -307,7 +307,7 @@ extern int cod_load_base(struct cod_manager *cod_mgr_obj,
* flags: COD_NOLOAD (don't load symbols) or COD_SYMB (load
* symbols).
- * pLib: Handle returned that can be used in calls to cod_close
+ * lib_obj: Handle returned that can be used in calls to cod_close
* and cod_get_section.
* Returns:
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dblldefs.h b/drivers/staging/tidspbridge/include/dspbridge/dblldefs.h
index da8abf4c3d4..23eca159563 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dblldefs.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dblldefs.h
@@ -379,7 +379,7 @@ typedef int(*dbll_load_sect_fxn) (struct dbll_library_obj *lib,
* target - Handle returned from dbll_create().
* file - Name of file to open.
* flags - If flags & DBLL_SYMB, load symbols.
* pLib - Location to store library handle on output.
* Returns:
* 0: Success.
* -ENOMEM: Memory allocation failure.
@@ -389,15 +389,15 @@ typedef int(*dbll_load_sect_fxn) (struct dbll_library_obj *lib,
* DBL initialized.
* Valid target.
* file != NULL.
- * pLib != NULL.
+ * lib_obj != NULL.
* dbll_attrs fopen function non-NULL.
* Ensures:
* Success: Valid *pLib.
* Failure: *pLib == NULL.
*/
typedef int(*dbll_open_fxn) (struct dbll_tar_obj *target, char *file,
dbll_flags flags,
- struct dbll_library_obj **pLib);
+ struct dbll_library_obj **lib_obj);
/*
* ======== dbll_read_sect ========
@@ -379,7 +379,7 @@ typedef int(*dbll_load_sect_fxn) (struct dbll_library_obj *lib,
* file - Name of file to open.
* flags - If flags & DBLL_SYMB, load symbols.
- * pLib - Location to store library handle on output.
+ * lib_obj - Location to store library handle on output.
* Returns:
* 0: Success.
@@ -389,15 +389,15 @@ typedef int(*dbll_load_sect_fxn) (struct dbll_library_obj *lib,
* dbll_attrs fopen function non-NULL.
* Ensures:
- * Success: Valid *pLib.
- * Failure: *pLib == NULL.
+ * Success: Valid *lib_obj.
+ * Failure: *lib_obj == NULL.
*/
typedef int(*dbll_open_fxn) (struct dbll_tar_obj *target, char *file,
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dev.h b/drivers/staging/tidspbridge/include/dspbridge/dev.h
index 68aa0b15930..a646402fb70 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dev.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dev.h
@@ -43,7 +43,7 @@
* arb: Handle to a Device Object.
* dev_ctxt: Handle to Bridge driver defined device info.
* dsp_addr: Address on DSP board (Destination).
* pHostBuf: Pointer to host buffer (Source).
* ul_num_bytes: Number of bytes to transfer.
* ulMemType: Memory space on DSP to which to transfer.
* Returns:
@@ -51,12 +51,12 @@
* arb is invalid.
* Requires:
* DEV Initialized.
- * pHostBuf != NULL
+ * host_buf != NULL
* Ensures:
*/
extern u32 dev_brd_write_fxn(void *arb,
u32 ulDspAddr,
- void *pHostBuf, u32 ul_num_bytes, u32 mem_space);
+ void *host_buf, u32 ul_num_bytes, u32 mem_space);
/*
* ======== dev_create_device ========
@@ -68,7 +68,7 @@ extern u32 dev_brd_write_fxn(void *arb,
* driver_file_name: Name of Bridge driver PE DLL file to load. If the
* absolute path is not provided, the file is loaded
* through 'Bridge's module search path.
- * pHostConfig: Host configuration information, to be passed down
+ * host_config: Host configuration information, to be passed down
* to the Bridge driver when bridge_dev_create() is called.
* pDspConfig: DSP resources, to be passed down to the Bridge driver
* when bridge_dev_create() is called.
@@ -82,7 +82,7 @@ extern u32 dev_brd_write_fxn(void *arb,
* DEV Initialized.
* device_obj != NULL.
* driver_file_name != NULL.
- * pHostConfig != NULL.
+ * host_config != NULL.
* pDspConfig != NULL.
* Ensures:
* 0: *device_obj will contain handle to the new device object.
@@ -103,7 +103,7 @@ extern int dev_create_device(OUT struct dev_object
* driver_file_name: Name of Bridge driver PE DLL file to load. If the
* absolute path is not provided, the file is loaded
* through 'Bridge's module search path.
- * pHostConfig: Host configuration information, to be passed down
+ * host_config: Host configuration information, to be passed down
* to the Bridge driver when bridge_dev_create() is called.
* pDspConfig: DSP resources, to be passed down to the Bridge driver
* when bridge_dev_create() is called.
@@ -117,7 +117,7 @@ extern int dev_create_device(OUT struct dev_object
* DEV Initialized.
* device_obj != NULL.
* driver_file_name != NULL.
- * pHostConfig != NULL.
+ * host_config != NULL.
* pDspConfig != NULL.
* Ensures:
* 0: *device_obj will contain handle to the new device object.
@@ -128,7 +128,7 @@ extern int dev_create_iva_device(OUT struct dev_object
**device_obj,
IN CONST char *driver_file_name,
IN CONST struct cfg_hostres
- *pHostConfig,
+ *host_config,
struct cfg_devnode *dev_node_obj);
/*
@@ -439,7 +439,7 @@ extern struct dev_object *dev_get_next(struct dev_object
* Requires:
* DEV Initialized.
* Valid hdev_obj.
- * phNodeMgr != NULL.
+ * node_man != NULL.
* Ensures:
*/
extern void dev_get_msg_mgr(struct dev_object *hdev_obj,
@@ -452,21 +452,21 @@ extern void dev_get_msg_mgr(struct dev_object *hdev_obj,
* accessor function
* Parameters:
* hdev_obj: Handle to the Dev Object
* phNodeMgr: Location where Handle to the Node Manager will be
* returned..
* Returns:
* 0: Success
* -EFAULT: Invalid Dev Object handle.
* Requires:
* DEV Initialized.
- * phNodeMgr is not null
+ * node_man is not null
* Ensures:
* 0: *phNodeMgr contains a handle to a Node manager object.
* else: *phNodeMgr is NULL.
*/
extern int dev_get_node_manager(struct dev_object
*hdev_obj,
- OUT struct node_mgr **phNodeMgr);
+ OUT struct node_mgr **node_man);
/*
* ======== dev_get_symbol ========
@@ -43,7 +43,7 @@
* dev_ctxt: Handle to Bridge driver defined device info.
* dsp_addr: Address on DSP board (Destination).
- * pHostBuf: Pointer to host buffer (Source).
+ * host_buf: Pointer to host buffer (Source).
* ul_num_bytes: Number of bytes to transfer.
* ulMemType: Memory space on DSP to which to transfer.
@@ -452,21 +452,21 @@ extern void dev_get_msg_mgr(struct dev_object *hdev_obj,
* Parameters:
* hdev_obj: Handle to the Dev Object
- * phNodeMgr: Location where Handle to the Node Manager will be
+ * node_man: Location where Handle to the Node Manager will be
* returned..
* Returns:
@@ -452,21 +452,21 @@ extern void dev_get_msg_mgr(struct dev_object *hdev_obj,
* Ensures:
- * 0: *phNodeMgr contains a handle to a Node manager object.
- * else: *phNodeMgr is NULL.
+ * 0: *node_man contains a handle to a Node manager object.
+ * else: *node_man is NULL.
*/
extern int dev_get_node_manager(struct dev_object
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dspdefs.h b/drivers/staging/tidspbridge/include/dspbridge/dspdefs.h
index 42930ccf6c3..e3c72320693 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dspdefs.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dspdefs.h
@@ -143,7 +143,7 @@ typedef int(*fxn_brd_memcopy) (struct bridge_dev_context
* Parameters:
* dev_ctxt: Handle to Bridge driver defined device info.
* dsp_addr: Address on DSP board (Destination).
* pHostBuf: Pointer to host buffer (Source).
* ul_num_bytes: Number of bytes to transfer.
* ulMemType: Memory space on DSP to which to transfer.
* Returns:
@@ -152,12 +152,12 @@ typedef int(*fxn_brd_memcopy) (struct bridge_dev_context
* -EPERM: Other, unspecified error.
* Requires:
* dev_ctxt != NULL;
- * pHostBuf != NULL.
+ * host_buf != NULL.
* Ensures:
*/
typedef int(*fxn_brd_memwrite) (struct bridge_dev_context
* dev_ctxt,
- IN u8 *pHostBuf,
+ IN u8 *host_buf,
u32 dsp_addr, u32 ul_num_bytes,
u32 ulMemType);
@@ -248,7 +248,7 @@ typedef int(*fxn_brd_status) (struct bridge_dev_context *dev_ctxt,
* buffer.
* Parameters:
* dev_ctxt: Handle to Bridge driver defined device info.
* pHostBuf: Pointer to host buffer (Destination).
* dsp_addr: Address on DSP board (Source).
* ul_num_bytes: Number of bytes to transfer.
* ulMemType: Memory space on DSP from which to transfer.
@@ -258,12 +258,12 @@ typedef int(*fxn_brd_status) (struct bridge_dev_context *dev_ctxt,
* -EPERM: Other, unspecified error.
* Requires:
* dev_ctxt != NULL;
- * pHostBuf != NULL.
+ * host_buf != NULL.
* Ensures:
* Will not write more than ul_num_bytes bytes into pHostBuf.
*/
typedef int(*fxn_brd_read) (struct bridge_dev_context *dev_ctxt,
- OUT u8 *pHostBuf,
+ OUT u8 *host_buf,
u32 dsp_addr,
u32 ul_num_bytes, u32 ulMemType);
@@ -275,7 +275,7 @@ typedef int(*fxn_brd_read) (struct bridge_dev_context *dev_ctxt,
* Parameters:
* dev_ctxt: Handle to Bridge driver defined device info.
* dsp_addr: Address on DSP board (Destination).
* pHostBuf: Pointer to host buffer (Source).
* ul_num_bytes: Number of bytes to transfer.
* ulMemType: Memory space on DSP to which to transfer.
* Returns:
@@ -284,11 +284,11 @@ typedef int(*fxn_brd_read) (struct bridge_dev_context *dev_ctxt,
* -EPERM: Other, unspecified error.
* Requires:
* dev_ctxt != NULL;
- * pHostBuf != NULL.
+ * host_buf != NULL.
* Ensures:
*/
typedef int(*fxn_brd_write) (struct bridge_dev_context *dev_ctxt,
- IN u8 *pHostBuf,
+ IN u8 *host_buf,
u32 dsp_addr,
u32 ul_num_bytes, u32 ulMemType);
@@ -442,7 +442,7 @@ typedef int(*fxn_chnl_close) (struct chnl_object *chnl_obj);
* address is specified for channels opened in direct I/O mode.
* Parameters:
* chnl_obj: Channel object handle.
* pHostBuf: Host buffer address source.
* byte_size: Number of PC bytes to transfer. A zero value indicates
* that this buffer is the last in the output channel.
* A zero value is invalid for an input channel.
@@ -451,7 +451,7 @@ typedef int(*fxn_chnl_close) (struct chnl_object *chnl_obj);
* dw_arg: A user argument that travels with the buffer.
* Returns:
* 0: Success;
- * -EFAULT: Invalid chnl_obj or pHostBuf.
+ * -EFAULT: Invalid chnl_obj or host_buf.
* -EPERM: User cannot mark EOS on an input channel.
* -ECANCELED: I/O has been cancelled on this channel. No further
* I/O is allowed.
@@ -472,7 +472,7 @@ typedef int(*fxn_chnl_close) (struct chnl_object *chnl_obj);
*/
typedef int(*fxn_chnl_addioreq) (struct chnl_object
* chnl_obj,
- void *pHostBuf,
+ void *host_buf,
u32 byte_size,
u32 buf_size,
OPTIONAL u32 dw_dsp_addr, u32 dw_arg);
@@ -486,12 +486,12 @@ typedef int(*fxn_chnl_addioreq) (struct chnl_object
* chnl_obj: Channel object handle.
* timeout: A value of CHNL_IOCNOWAIT will simply dequeue the
* first available IOC.
* pIOC: On output, contains host buffer address, bytes
* transferred, and status of I/O completion.
- * pIOC->status: See chnldefs.h.
+ * chan_ioc->status: See chnldefs.h.
* Returns:
* 0: Success.
- * -EFAULT: Invalid chnl_obj or pIOC.
+ * -EFAULT: Invalid chnl_obj or chan_ioc.
* -EREMOTEIO: CHNL_IOCNOWAIT was specified as the timeout parameter
* yet no I/O completions were queued.
* Requires:
@@ -503,7 +503,7 @@ typedef int(*fxn_chnl_addioreq) (struct chnl_object
*/
typedef int(*fxn_chnl_getioc) (struct chnl_object *chnl_obj,
u32 timeout,
- OUT struct chnl_ioc *pIOC);
+ OUT struct chnl_ioc *chan_ioc);
/*
* ======== bridge_chnl_cancel_io ========
@@ -551,14 +551,14 @@ typedef int(*fxn_chnl_flushio) (struct chnl_object *chnl_obj,
* Retrieve information related to a channel.
* Parameters:
* chnl_obj: Handle to a valid channel object, or NULL.
- * pInfo: Location to store channel info.
+ * channel_info: Location to store channel info.
* Returns:
* 0: Success;
- * -EFAULT: Invalid chnl_obj or pInfo.
+ * -EFAULT: Invalid chnl_obj or channel_info.
* Requires:
* Ensures:
- * 0: pInfo points to a filled in chnl_info struct,
- * if (pInfo != NULL).
+ * 0: channel_info points to a filled in chnl_info struct,
+ * if (channel_info != NULL).
*/
typedef int(*fxn_chnl_getinfo) (struct chnl_object *chnl_obj,
OUT struct chnl_info *channel_info);
@@ -143,7 +143,7 @@ typedef int(*fxn_brd_memcopy) (struct bridge_dev_context
* dev_ctxt: Handle to Bridge driver defined device info.
* dsp_addr: Address on DSP board (Destination).
- * pHostBuf: Pointer to host buffer (Source).
+ * host_buf: Pointer to host buffer (Source).
* ul_num_bytes: Number of bytes to transfer.
* ulMemType: Memory space on DSP to which to transfer.
@@ -248,7 +248,7 @@ typedef int(*fxn_brd_status) (struct bridge_dev_context *dev_ctxt,
* Parameters:
* dev_ctxt: Handle to Bridge driver defined device info.
- * pHostBuf: Pointer to host buffer (Destination).
+ * host_buf: Pointer to host buffer (Destination).
* dsp_addr: Address on DSP board (Source).
* ul_num_bytes: Number of bytes to transfer.
@@ -258,12 +258,12 @@ typedef int(*fxn_brd_status) (struct bridge_dev_context *dev_ctxt,
* Ensures:
- * Will not write more than ul_num_bytes bytes into pHostBuf.
+ * Will not write more than ul_num_bytes bytes into host_buf.
*/
typedef int(*fxn_brd_read) (struct bridge_dev_context *dev_ctxt,
@@ -275,7 +275,7 @@ typedef int(*fxn_brd_read) (struct bridge_dev_context *dev_ctxt,
* dev_ctxt: Handle to Bridge driver defined device info.
* dsp_addr: Address on DSP board (Destination).
- * pHostBuf: Pointer to host buffer (Source).
+ * host_buf: Pointer to host buffer (Source).
* ul_num_bytes: Number of bytes to transfer.
* ulMemType: Memory space on DSP to which to transfer.
@@ -442,7 +442,7 @@ typedef int(*fxn_chnl_close) (struct chnl_object *chnl_obj);
* Parameters:
* chnl_obj: Channel object handle.
- * pHostBuf: Host buffer address source.
+ * host_buf: Host buffer address source.
* byte_size: Number of PC bytes to transfer. A zero value indicates
* that this buffer is the last in the output channel.
@@ -486,12 +486,12 @@ typedef int(*fxn_chnl_addioreq) (struct chnl_object
* timeout: A value of CHNL_IOCNOWAIT will simply dequeue the
* first available IOC.
- * pIOC: On output, contains host buffer address, bytes
+ * chan_ioc: On output, contains host buffer address, bytes
* transferred, and status of I/O completion.
diff --git a/drivers/staging/tidspbridge/include/dspbridge/node.h b/drivers/staging/tidspbridge/include/dspbridge/node.h
index 9dfa3a8ac8c..70f3e8988e1 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/node.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/node.h
@@ -217,7 +217,7 @@ extern int node_create(struct node_object *hnode);
* Each DEV object should have exactly one NODE Manager object.
*
* Parameters:
* phNodeMgr: Location to store node manager handle on output.
* hdev_obj: Device for this processor.
* Returns:
* 0: Success;
@@ -225,13 +225,13 @@ extern int node_create(struct node_object *hnode);
* -EPERM: General failure.
* Requires:
* node_init(void) called.
- * phNodeMgr != NULL.
+ * node_man != NULL.
* hdev_obj != NULL.
* Ensures:
* 0: Valide *phNodeMgr.
* error: *phNodeMgr == NULL.
*/
-extern int node_create_mgr(OUT struct node_mgr **phNodeMgr,
+extern int node_create_mgr(OUT struct node_mgr **node_man,
struct dev_object *hdev_obj);
/*
@@ -392,14 +392,14 @@ extern int node_get_message(struct node_object *hnode,
* Retrieve the Nldr manager
* Parameters:
* hnode_mgr: Node Manager
* phNldrObj: Pointer to a Nldr manager handle
* Returns:
* 0: Success.
* -EFAULT: Invalid hnode.
* Ensures:
*/
extern int node_get_nldr_obj(struct node_mgr *hnode_mgr,
- OUT struct nldr_object **phNldrObj);
+ OUT struct nldr_object **nldr_ovlyobj);
/*
* ======== node_init ========
@@ -217,7 +217,7 @@ extern int node_create(struct node_object *hnode);
*
* Parameters:
- * phNodeMgr: Location to store node manager handle on output.
+ * node_man: Location to store node manager handle on output.
* hdev_obj: Device for this processor.
* Returns:
@@ -225,13 +225,13 @@ extern int node_create(struct node_object *hnode);
* hdev_obj != NULL.
* Ensures:
- * 0: Valide *phNodeMgr.
- * error: *phNodeMgr == NULL.
+ * 0: Valide *node_man.
+ * error: *node_man == NULL.
*/
@@ -392,14 +392,14 @@ extern int node_get_message(struct node_object *hnode,
* Parameters:
* hnode_mgr: Node Manager
- * phNldrObj: Pointer to a Nldr manager handle
+ * nldr_ovlyobj: Pointer to a Nldr manager handle
* Returns:
* 0: Success.
diff --git a/drivers/staging/tidspbridge/include/dspbridge/nodepriv.h b/drivers/staging/tidspbridge/include/dspbridge/nodepriv.h
index 42e1a943617..0dc6dc7f43c 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/nodepriv.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/nodepriv.h
@@ -110,16 +110,16 @@ extern int node_get_channel_id(struct node_object *hnode,
* Get the STRM manager for a node.
* Parameters:
* hnode: Node allocated with node_allocate().
* phStrmMgr: Location to store STRM manager on output.
* Returns:
* 0: Success.
* -EFAULT: Invalid hnode.
* Requires:
- * phStrmMgr != NULL.
+ * strm_man != NULL.
* Ensures:
*/
extern int node_get_strm_mgr(struct node_object *hnode,
- struct strm_mgr **phStrmMgr);
+ struct strm_mgr **strm_man);
/*
* ======== node_get_timeout ========
@@ -110,16 +110,16 @@ extern int node_get_channel_id(struct node_object *hnode,
* Parameters:
* hnode: Node allocated with node_allocate().
- * phStrmMgr: Location to store STRM manager on output.
+ * strm_man: Location to store STRM manager on output.
* Returns:
* 0: Success.
diff --git a/drivers/staging/tidspbridge/include/dspbridge/strm.h b/drivers/staging/tidspbridge/include/dspbridge/strm.h
index c4a4d652a64..6572442f6da 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/strm.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/strm.h
@@ -75,7 +75,7 @@ extern int strm_close(struct strm_object *stream_obj,
* Create a STRM manager object. This object holds information about the
* device needed to open streams.
* Parameters:
* phStrmMgr: Location to store handle to STRM manager object on
* output.
* dev_obj: Device for this processor.
* Returns:
@@ -84,13 +84,13 @@ extern int strm_close(struct strm_object *stream_obj,
* -EPERM: General failure.
* Requires:
* strm_init(void) called.
- * phStrmMgr != NULL.
+ * strm_man != NULL.
* dev_obj != NULL.
* Ensures:
* 0: Valid *phStrmMgr.
* error: *phStrmMgr == NULL.
*/
-extern int strm_create(OUT struct strm_mgr **phStrmMgr,
+extern int strm_create(OUT struct strm_mgr **strm_man,
struct dev_object *dev_obj);
/*
@@ -254,7 +254,7 @@ extern int strm_issue(struct strm_object *stream_obj, IN u8 * pbuf,
* index: Stream index.
* pattr: Pointer to structure containing attributes to be
* applied to stream. Cannot be NULL.
* phStrm: Location to store stream handle on output.
* Returns:
* 0: Success.
* -EFAULT: Invalid hnode.
@@ -264,15 +264,15 @@ extern int strm_issue(struct strm_object *stream_obj, IN u8 * pbuf,
* -EINVAL: Invalid index.
* Requires:
* strm_init(void) called.
- * phStrm != NULL.
+ * strm_objct != NULL.
* pattr != NULL.
* Ensures:
* 0: *phStrm is valid.
* error: *phStrm == NULL.
*/
extern int strm_open(struct node_object *hnode, u32 dir,
u32 index, IN struct strm_attr *pattr,
- OUT struct strm_object **phStrm,
+ OUT struct strm_object **strm_objct,
struct process_context *pr_ctxt);
/*
@@ -75,7 +75,7 @@ extern int strm_close(struct strm_object *stream_obj,
* device needed to open streams.
* Parameters:
- * phStrmMgr: Location to store handle to STRM manager object on
+ * strm_man: Location to store handle to STRM manager object on
* output.
* dev_obj: Device for this processor.
@@ -84,13 +84,13 @@ extern int strm_close(struct strm_object *stream_obj,
* dev_obj != NULL.
* Ensures:
- * 0: Valid *phStrmMgr.
- * error: *phStrmMgr == NULL.
+ * 0: Valid *strm_man.
+ * error: *strm_man == NULL.
*/
@@ -254,7 +254,7 @@ extern int strm_issue(struct strm_object *stream_obj, IN u8 * pbuf,
* pattr: Pointer to structure containing attributes to be
* applied to stream. Cannot be NULL.
- * phStrm: Location to store stream handle on output.
+ * strm_objct: Location to store stream handle on output.
* Returns:
* 0: Success.
@@ -264,15 +264,15 @@ extern int strm_issue(struct strm_object *stream_obj, IN u8 * pbuf,
* pattr != NULL.
* Ensures:
- * 0: *phStrm is valid.
- * error: *phStrm == NULL.
+ * 0: *strm_objct is valid.
+ * error: *strm_objct == NULL.
*/
extern int strm_open(struct node_object *hnode, u32 dir,